@@ -17,6 +17,7 @@
 import os
 import shutil
 
+from storlets.agent.common.utils import DEFAULT_PY2, DEFAULT_PY3
 from storlets.gateway.common.stob import StorletRequest
 from storlets.gateway.gateways.base import StorletGatewayBase
 from storlets.gateway.gateways.docker.runtime import RunTimePaths, \
@@ -71,6 +72,8 @@ class DockerStorletRequest(StorletRequest):
 
         self.storlet_main = self.options['storlet_main']
         self.storlet_language = self.options['storlet_language']
+        self.storlet_language_version = \
+            self.options.get('storlet_language_version')
 
         if self.options.get('storlet_dependency'):
             self.dependencies = [
@@ -125,6 +128,16 @@ class StorletGatewayDocker(StorletGatewayBase):
             if '-' not in name or '.' not in name:
                 raise ValueError('Storlet name is incorrect')
         elif params['Language'].lower() == 'python':
+            # support both py2 and py3
+            try:
+                version = int(float(params.get('Language-Version', 2)))
+            except ValueError:
+                raise ValueError('Language-Version is invalid')
+
+            if version not in [2, DEFAULT_PY2, 3, DEFAULT_PY3]:
+                # TODO(kota_): more strict version check should be nice.
+                raise ValueError('Not supported version specified')
+
             if name.endswith('.py'):
                 cls_name = params['Main']
                 if not cls_name.startswith(name[:-3] + '.'):
@@ -199,8 +212,9 @@ class StorletGatewayDocker(StorletGatewayBase):
         run_time_sbox.activate_storlet_daemon(sreq, docker_updated)
         self._add_system_params(sreq)
 
-        slog_path = self.paths.slog_path(sreq.storlet_main)
-        storlet_pipe_path = self.paths.host_storlet_pipe(sreq.storlet_main)
+        slog_path = self.paths.get_host_slog_path(sreq.storlet_main)
+        storlet_pipe_path = \
+            self.paths.get_host_storlet_pipe(sreq.storlet_main)
 
         sprotocol = StorletInvocationProtocol(sreq,
                                               storlet_pipe_path,
@@ -225,7 +239,7 @@ class StorletGatewayDocker(StorletGatewayBase):
         :params params: Request parameters
         """
         sreq.params['storlet_execution_path'] = self. \
-            paths.sbox_storlet_exec(sreq.storlet_main)
+            paths.get_sbox_storlet_dir(sreq.storlet_main)
 
     def _upload_storlet_logs(self, slog_path, sreq):
         """
@@ -260,10 +274,10 @@ class StorletGatewayDocker(StorletGatewayBase):
         # Determine the cache we are to work with
         # e.g. dependency or storlet
         if is_storlet:
-            cache_dir = self.paths.get_host_storlet_cache_dir()
+            cache_dir = self.paths.host_storlet_cache_dir
             get_func = sreq.file_manager.get_storlet
         else:
-            cache_dir = self.paths.get_host_dependency_cache_dir()
+            cache_dir = self.paths.host_dependency_cache_dir
             get_func = sreq.file_manager.get_dependency
 
         if not os.path.exists(cache_dir):
@@ -287,7 +301,8 @@ class StorletGatewayDocker(StorletGatewayBase):
             # only, and not for dependencies.
             # This will change when we will head dependencies as well
             fstat = os.stat(cache_target_path)
-            storlet_or_size = long(sreq.options['storlet_content_length'])
+            storlet_or_size = int(
+                sreq.options['storlet_content_length'].rstrip("L"))
             storlet_or_time = float(sreq.options['storlet_x_timestamp'])
             b_storlet_size_changed = fstat.st_size != storlet_or_size
             b_storlet_file_updated = float(fstat.st_mtime) < storlet_or_time
@@ -316,7 +331,8 @@ class StorletGatewayDocker(StorletGatewayBase):
         # 1. The Docker container does not hold a copy of the object
         # 2. The Docker container holds an older version of the object
         update_docker = False
-        docker_storlet_path = self.paths.host_storlet(sreq.storlet_main)
+        docker_storlet_path = \
+            self.paths.get_host_storlet_dir(sreq.storlet_main)
         docker_target_path = os.path.join(docker_storlet_path, obj_name)
 
         if not os.path.exists(docker_storlet_path):
@@ -353,7 +369,7 @@ class StorletGatewayDocker(StorletGatewayBase):
         :returns: True if the Docker container was updated
         """
         # where at the host side, reside the storlet containers
-        storlet_path = self.paths.host_storlet_prefix()
+        storlet_path = self.paths.host_storlet_base_dir
         if not os.path.exists(storlet_path):
             os.makedirs(storlet_path, 0o755)
 
